==> aws-sdk-cpp-1.11.710-1-x86_64.pkg.tar.zst: usr/include/aws/medialive/model/InputSecurityGroup.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSMap.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/medialive/MediaLive_EXPORTS.h>
#include <aws/medialive/model/InputSecurityGroupState.h>
#include <aws/medialive/model/InputWhitelistRule.h>

#include <utility>

namespace Aws {
namespace Utils {
namespace Json {
class JsonValue;
class JsonView;
}  // namespace Json
}  // namespace Utils
namespace MediaLive {
namespace Model {

/**
 * An Input Security Group<p><h3>See Also:</h3>   <a
 * href="http://docs.aws.amazon.com/goto/WebAPI/medialive-2017-10-14/InputSecurityGroup">AWS
 * API Reference</a></p>
 */
class InputSecurityGroup {
 public:
  AWS_MEDIALIVE_API InputSecurityGroup() = default;
  AWS_MEDIALIVE_API InputSecurityGroup(Aws::Utils::Json::JsonView jsonValue);
  AWS_MEDIALIVE_API InputSecurityGroup& operator=(Aws::Utils::Json::JsonView jsonValue);
  AWS_MEDIALIVE_API Aws::Utils::Json::JsonValue Jsonize() const;

  ///@{
  /**
   * Unique ARN of Input Security Group
   */
  inline const Aws::String& GetArn() const { return m_arn; }
  inline bool ArnHasBeenSet() const { return m_arnHasBeenSet; }
  template <typename ArnT = Aws::String>
  void SetArn(ArnT&& value) {
    m_arnHasBeenSet = true;
    m_arn = std::forward<ArnT>(value);
  }
  template <typename ArnT = Aws::String>
  InputSecurityGroup& WithArn(ArnT&& value) {
    SetArn(std::forward<ArnT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * The Id of the Input Security Group
   */
  inline const Aws::String& GetId() const { return m_id; }
  inline bool IdHasBeenSet() const { return m_idHasBeenSet; }
  template <typename IdT = Aws::String>
  void SetId(IdT&& value) {
    m_idHasBeenSet = true;
    m_id = std::forward<IdT>(value);
  }
  template <typename IdT = Aws::String>
  InputSecurityGroup& WithId(IdT&& value) {
    SetId(std::forward<IdT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * The list of inputs currently using this Input Security Group.
   */
  inline const Aws::Vector<Aws::String>& GetInputs() const { return m_inputs; }
  inline bool InputsHasBeenSet() const { return m_inputsHasBeenSet; }
  template <typename InputsT = Aws::Vector<Aws::String>>
  void SetInputs(InputsT&& value) {
    m_inputsHasBeenSet = true;
    m_inputs = std::forward<InputsT>(value);
  }
  template <typename InputsT = Aws::Vector<Aws::String>>
  InputSecurityGroup& WithInputs(InputsT&& value) {
    SetInputs(std::forward<InputsT>(value));
    return *this;
  }
  template <typename InputsT = Aws::String>
  InputSecurityGroup& AddInputs(InputsT&& value) {
    m_inputsHasBeenSet = true;
    m_inputs.emplace_back(std::forward<InputsT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * The current state of the Input Security Group.
   */
  inline InputSecurityGroupState GetState() const { return m_state; }
  inline bool StateHasBeenSet() const { return m_stateHasBeenSet; }
  inline void SetState(InputSecurityGroupState value) {
    m_stateHasBeenSet = true;
    m_state = value;
  }
  inline InputSecurityGroup& WithState(InputSecurityGroupState value) {
    SetState(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * A collection of key-value pairs.
   */
  inline const Aws::Map<Aws::String, Aws::String>& GetTags() const { return m_tags; }
  inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
  template <typename TagsT = Aws::Map<Aws::String, Aws::String>>
  void SetTags(TagsT&& value) {
    m_tagsHasBeenSet = true;
    m_tags = std::forward<TagsT>(value);
  }
  template <typename TagsT = Aws::Map<Aws::String, Aws::String>>
  InputSecurityGroup& WithTags(TagsT&& value) {
    SetTags(std::forward<TagsT>(value));
    return *this;
  }
  template <typename TagsKeyT = Aws::String, typename TagsValueT = Aws::String>
  InputSecurityGroup& AddTags(TagsKeyT&& key, TagsValueT&& value) {
    m_tagsHasBeenSet = true;
    m_tags.emplace(std::forward<TagsKeyT>(key), std::forward<TagsValueT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * Whitelist rules and their sync status
   */
  inline const Aws::Vector<InputWhitelistRule>& GetWhitelistRules() const { return m_whitelistRules; }
  inline bool WhitelistRulesHasBeenSet() const { return m_whitelistRulesHasBeenSet; }
  template <typename WhitelistRulesT = Aws::Vector<InputWhitelistRule>>
  void SetWhitelistRules(WhitelistRulesT&& value) {
    m_whitelistRulesHasBeenSet = true;
    m_whitelistRules = std::forward<WhitelistRulesT>(value);
  }
  template <typename WhitelistRulesT = Aws::Vector<InputWhitelistRule>>
  InputSecurityGroup& WithWhitelistRules(WhitelistRulesT&& value) {
    SetWhitelistRules(std::forward<WhitelistRulesT>(value));
    return *this;
  }
  template <typename WhitelistRulesT = InputWhitelistRule>
  InputSecurityGroup& AddWhitelistRules(WhitelistRulesT&& value) {
    m_whitelistRulesHasBeenSet = true;
    m_whitelistRules.emplace_back(std::forward<WhitelistRulesT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_arn;

  Aws::String m_id;

  Aws::Vector<Aws::String> m_inputs;

  InputSecurityGroupState m_state{InputSecurityGroupState::NOT_SET};

  Aws::Map<Aws::String, Aws::String> m_tags;

  Aws::Vector<InputWhitelistRule> m_whitelistRules;
  bool m_arnHasBeenSet = false;
  bool m_idHasBeenSet = false;
  bool m_inputsHasBeenSet = false;
  bool m_stateHasBeenSet = false;
  bool m_tagsHasBeenSet = false;
  bool m_whitelistRulesHasBeenSet = false;
};

}  // namespace Model
}  // namespace MediaLive
}  // namespace Aws

==> aws-sdk-cpp-1.11.744-1-x86_64.pkg.tar.zst: usr/include/aws/medialive/model/InputSecurityGroup.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSMap.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/medialive/MediaLive_EXPORTS.h>
#include <aws/medialive/model/InputSecurityGroupState.h>
#include <aws/medialive/model/InputWhitelistRule.h>

#include <utility>

namespace Aws {
namespace Utils {
namespace Json {
class JsonValue;
class JsonView;
}  // namespace Json
}  // namespace Utils
namespace MediaLive {
namespace Model {

/**
 * An Input Security Group<p><h3>See Also:</h3>   <a
 * href="http://docs.aws.amazon.com/goto/WebAPI/medialive-2017-10-14/InputSecurityGroup">AWS
 * API Reference</a></p>
 */
class InputSecurityGroup {
 public:
  AWS_MEDIALIVE_API InputSecurityGroup() = default;
  AWS_MEDIALIVE_API InputSecurityGroup(Aws::Utils::Json::JsonView jsonValue);
  AWS_MEDIALIVE_API InputSecurityGroup& operator=(Aws::Utils::Json::JsonView jsonValue);
  AWS_MEDIALIVE_API Aws::Utils::Json::JsonValue Jsonize() const;

  ///@{
  /**
   * Unique ARN of Input Security Group
   */
  inline const Aws::String& GetArn() const { return m_arn; }
  inline bool ArnHasBeenSet() const { return m_arnHasBeenSet; }
  template <typename ArnT = Aws::String>
  void SetArn(ArnT&& value) {
    m_arnHasBeenSet = true;
    m_arn = std::forward<ArnT>(value);
  }
  template <typename ArnT = Aws::String>
  InputSecurityGroup& WithArn(ArnT&& value) {
    SetArn(std::forward<ArnT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * The Id of the Input Security Group
   */
  inline const Aws::String& GetId() const { return m_id; }
  inline bool IdHasBeenSet() const { return m_idHasBeenSet; }
  template <typename IdT = Aws::String>
  void SetId(IdT&& value) {
    m_idHasBeenSet = true;
    m_id = std::forward<IdT>(value);
  }
  template <typename IdT = Aws::String>
  InputSecurityGroup& WithId(IdT&& value) {
    SetId(std::forward<IdT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * The list of inputs currently using this Input Security Group.
   */
  inline const Aws::Vector<Aws::String>& GetInputs() const { return m_inputs; }
  inline bool InputsHasBeenSet() const { return m_inputsHasBeenSet; }
  template <typename InputsT = Aws::Vector<Aws::String>>
  void SetInputs(InputsT&& value) {
    m_inputsHasBeenSet = true;
    m_inputs = std::forward<InputsT>(value);
  }
  template <typename InputsT = Aws::Vector<Aws::String>>
  InputSecurityGroup& WithInputs(InputsT&& value) {
    SetInputs(std::forward<InputsT>(value));
    return *this;
  }
  template <typename InputsT = Aws::String>
  InputSecurityGroup& AddInputs(InputsT&& value) {
    m_inputsHasBeenSet = true;
    m_inputs.emplace_back(std::forward<InputsT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * The current state of the Input Security Group.
   */
  inline InputSecurityGroupState GetState() const { return m_state; }
  inline bool StateHasBeenSet() const { return m_stateHasBeenSet; }
  inline void SetState(InputSecurityGroupState value) {
    m_stateHasBeenSet = true;
    m_state = value;
  }
  inline InputSecurityGroup& WithState(InputSecurityGroupState value) {
    SetState(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * A collection of key-value pairs.
   */
  inline const Aws::Map<Aws::String, Aws::String>& GetTags() const { return m_tags; }
  inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
  template <typename TagsT = Aws::Map<Aws::String, Aws::String>>
  void SetTags(TagsT&& value) {
    m_tagsHasBeenSet = true;
    m_tags = std::forward<TagsT>(value);
  }
  template <typename TagsT = Aws::Map<Aws::String, Aws::String>>
  InputSecurityGroup& WithTags(TagsT&& value) {
    SetTags(std::forward<TagsT>(value));
    return *this;
  }
  template <typename TagsKeyT = Aws::String, typename TagsValueT = Aws::String>
  InputSecurityGroup& AddTags(TagsKeyT&& key, TagsValueT&& value) {
    m_tagsHasBeenSet = true;
    m_tags.emplace(std::forward<TagsKeyT>(key), std::forward<TagsValueT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * Whitelist rules and their sync status
   */
  inline const Aws::Vector<InputWhitelistRule>& GetWhitelistRules() const { return m_whitelistRules; }
  inline bool WhitelistRulesHasBeenSet() const { return m_whitelistRulesHasBeenSet; }
  template <typename WhitelistRulesT = Aws::Vector<InputWhitelistRule>>
  void SetWhitelistRules(WhitelistRulesT&& value) {
    m_whitelistRulesHasBeenSet = true;
    m_whitelistRules = std::forward<WhitelistRulesT>(value);
  }
  template <typename WhitelistRulesT = Aws::Vector<InputWhitelistRule>>
  InputSecurityGroup& WithWhitelistRules(WhitelistRulesT&& value) {
    SetWhitelistRules(std::forward<WhitelistRulesT>(value));
    return *this;
  }
  template <typename WhitelistRulesT = InputWhitelistRule>
  InputSecurityGroup& AddWhitelistRules(WhitelistRulesT&& value) {
    m_whitelistRulesHasBeenSet = true;
    m_whitelistRules.emplace_back(std::forward<WhitelistRulesT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * The list of channels currently using this Input Security Group as their channel
   * security group.
   */
  inline const Aws::Vector<Aws::String>& GetChannels() const { return m_channels; }
  inline bool ChannelsHasBeenSet() const { return m_channelsHasBeenSet; }
  template <typename ChannelsT = Aws::Vector<Aws::String>>
  void SetChannels(ChannelsT&& value) {
    m_channelsHasBeenSet = true;
    m_channels = std::forward<ChannelsT>(value);
  }
  template <typename ChannelsT = Aws::Vector<Aws::String>>
  InputSecurityGroup& WithChannels(ChannelsT&& value) {
    SetChannels(std::forward<ChannelsT>(value));
    return *this;
  }
  template <typename ChannelsT = Aws::String>
  InputSecurityGroup& AddChannels(ChannelsT&& value) {
    m_channelsHasBeenSet = true;
    m_channels.emplace_back(std::forward<ChannelsT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_arn;

  Aws::String m_id;

  Aws::Vector<Aws::String> m_inputs;

  InputSecurityGroupState m_state{InputSecurityGroupState::NOT_SET};

  Aws::Map<Aws::String, Aws::String> m_tags;

  Aws::Vector<InputWhitelistRule> m_whitelistRules;

  Aws::Vector<Aws::String> m_channels;
  bool m_arnHasBeenSet = false;
  bool m_idHasBeenSet = false;
  bool m_inputsHasBeenSet = false;
  bool m_stateHasBeenSet = false;
  bool m_tagsHasBeenSet = false;
  bool m_whitelistRulesHasBeenSet = false;
  bool m_channelsHasBeenSet = false;
};

}  // namespace Model
}  // namespace MediaLive
}  // namespace Aws
